MovieBot Python API
====================

.. image:: https://img.shields.io/pypi/v/movie-bot-api.svg
   :target: https://img.shields.io/pypi/v/movie-bot-api.svg
   :alt: PyPI version info
.. image:: https://img.shields.io/pypi/pyversions/movie-bot-api.svg
   :target: https://pypi.python.org/pypi/movie-bot-api
   :alt: PyPI supported Python versions

易于使用的，灵活的，可扩展的，Movie Bot智能影音机器人官方Python API包装器

安装
-------------
使用pip安装:

.. code:: sh

    # Linux/macOS
    python3 -m pip install -U movie-bot-api

    # Windows
    py -3 -m pip install -U movie-bot-api